==> option-annotations-2.7.0-sources.jar: io/dekorate/option/config/VcsConfigFluentImpl.java <==
package io.dekorate.option.config;

import io.dekorate.kubernetes.config.ConfigurationFluentImpl;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class VcsConfigFluentImpl<A extends io.dekorate.option.config.VcsConfigFluent<A>> extends io.dekorate.kubernetes.config.ConfigurationFluentImpl<A> implements io.dekorate.option.config.VcsConfigFluent<A>{
  public VcsConfigFluentImpl() {
  }
  public VcsConfigFluentImpl(io.dekorate.option.config.VcsConfig instance) {
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withRemote(instance.getRemote()); 
    this.withHttpsPreferred(instance.getHttpsPreferred()); 
  }
  private java.lang.String remote;
  private java.lang.Boolean httpsPreferred;
  public java.lang.String getRemote() {
    return this.remote;
  }
  public A withRemote(java.lang.String remote) {
    this.remote=remote; return (A) this;
  }
  public java.lang.Boolean hasRemote() {
    return this.remote != null;
  }
  
  /**
   * Method is deprecated. use withRemote instead.
   */
  @java.lang.Deprecated
  public A withNewRemote(java.lang.String arg0) {
    return (A)withRemote(new String(arg0));
  }
  public java.lang.Boolean getHttpsPreferred() {
    return this.httpsPreferred;
  }
  public A withHttpsPreferred(java.lang.Boolean httpsPreferred) {
    this.httpsPreferred=httpsPreferred; return (A) this;
  }
  public java.lang.Boolean hasHttpsPreferred() {
    return this.httpsPreferred != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VcsConfigFluentImpl that = (VcsConfigFluentImpl) o;
    if (remote != null ? !remote.equals(that.remote) :that.remote != null) return false;
    if (httpsPreferred != null ? !httpsPreferred.equals(that.httpsPreferred) :that.httpsPreferred != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(remote,  httpsPreferred,  super.hashCode());
  }
  
}

==> option-annotations-2.11.3-sources.jar: io/dekorate/option/config/VcsConfigFluentImpl.java <==
package io.dekorate.option.config;

import io.dekorate.kubernetes.config.ConfigurationFluentImpl;
import java.lang.SuppressWarnings;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VcsConfigFluentImpl<A extends VcsConfigFluent<A>> extends ConfigurationFluentImpl<A> implements VcsConfigFluent<A>{
  public VcsConfigFluentImpl() {
  }
  public VcsConfigFluentImpl(io.dekorate.option.config.VcsConfig instance) {
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withRemote(instance.getRemote()); 
    this.withHttpsPreferred(instance.getHttpsPreferred()); 
  }
  private String remote;
  private Boolean httpsPreferred;
  public java.lang.String getRemote() {
    return this.remote;
  }
  public A withRemote(java.lang.String remote) {
    this.remote=remote; return (A) this;
  }
  public java.lang.Boolean hasRemote() {
    return this.remote != null;
  }
  public java.lang.Boolean getHttpsPreferred() {
    return this.httpsPreferred;
  }
  public A withHttpsPreferred(java.lang.Boolean httpsPreferred) {
    this.httpsPreferred=httpsPreferred; return (A) this;
  }
  public java.lang.Boolean hasHttpsPreferred() {
    return this.httpsPreferred != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VcsConfigFluentImpl that = (VcsConfigFluentImpl) o;
    if (remote != null ? !remote.equals(that.remote) :that.remote != null) return false;
    if (httpsPreferred != null ? !httpsPreferred.equals(that.httpsPreferred) :that.httpsPreferred != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(remote,  httpsPreferred,  super.hashCode());
  }
  public java.lang.String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (remote != null) { sb.append("remote:"); sb.append(remote + ","); }
    if (httpsPreferred != null) { sb.append("httpsPreferred:"); sb.append(httpsPreferred); }
    sb.append("}");
    return sb.toString();
  }
  public A withHttpsPreferred() {
    return withHttpsPreferred(true);
  }
  
}
